@@ -154,7 +154,6 @@ desktop_clock_widget_load_svg_file(const gchar* path,
   }
 
   *pHandle = handle;
-
   return handle != NULL;
 }
 
@@ -263,18 +262,13 @@ desktop_clock_widget_render_background(cairo_t* main_cr,
   cairo_scale(cr,  
 	      desktop_plugin->priv->clock_width/desktop_plugin->priv->image_width,  
 	      desktop_plugin->priv->clock_height/desktop_plugin->priv->image_height);
-
-
-
-
-
-
-
-
   cairo_set_operator(cr, CAIRO_OPERATOR_OVER);
-  rsvg_handle_render_cairo(theme->drop_shadow, cr);
-  rsvg_handle_render_cairo(theme->face, cr);
-  rsvg_handle_render_cairo(theme->marks, cr);
+  if(theme->drop_shadow)
+    rsvg_handle_render_cairo(theme->drop_shadow, cr);
+  if(theme->face)
+    rsvg_handle_render_cairo(theme->face, cr);
+  if(theme->marks)
+    rsvg_handle_render_cairo(theme->marks, cr);
   cairo_destroy(cr);    
   cairo_destroy(cr);
 }
@@ -297,9 +291,12 @@ desktop_clock_widget_render_foreground(cairo_t* main_cr,
    	      desktop_plugin->priv->clock_height/desktop_plugin->priv->image_height); 
   
   cairo_set_operator(cr, CAIRO_OPERATOR_OVER);
-  rsvg_handle_render_cairo(theme->face_shadow, cr);
-  rsvg_handle_render_cairo(theme->glass, cr);
-  rsvg_handle_render_cairo(theme->frame, cr);
+  if(theme->face_shadow)
+    rsvg_handle_render_cairo(theme->face_shadow, cr);
+  if(theme->glass)
+    rsvg_handle_render_cairo(theme->glass, cr);
+  if(theme->frame)
+    rsvg_handle_render_cairo(theme->frame, cr);
   cairo_destroy(cr);
 }
 
@@ -564,8 +561,15 @@ desktop_clock_widget_init_theme(DesktopClockWidgetHomePlugin* desktop_plugin)
   if(desktop_clock_widget_read_theme(theme))
   {
     RsvgDimensionData dimension_data;
-    rsvg_handle_get_dimensions(theme->drop_shadow,
-			       &dimension_data);
+    if(theme->drop_shadow)
+      rsvg_handle_get_dimensions(theme->drop_shadow,
+				 &dimension_data);
+    else if(theme->face_shadow)
+      rsvg_handle_get_dimensions(theme->face_shadow,
+				 &dimension_data);
+    else if(theme->face)
+      rsvg_handle_get_dimensions(theme->face,
+				 &dimension_data);
     desktop_plugin->priv->image_width = dimension_data.width;
     desktop_plugin->priv->image_height = dimension_data.height;
     cairo_t* main_cr = gdk_cairo_create(GDK_DRAWABLE(GTK_WIDGET(desktop_plugin)->window));
@@ -594,12 +598,19 @@ desktop_clock_widget_init_theme(DesktopClockWidgetHomePlugin* desktop_plugin)
     desktop_plugin->priv->minute_shadow_svg_handle = theme->minute_hand_shadow;
     desktop_plugin->priv->second_svg_handle = theme->second_hand;
     desktop_plugin->priv->second_shadow_svg_handle = theme->second_hand_shadow;
-    g_object_ref(desktop_plugin->priv->hour_svg_handle);
-    g_object_ref(desktop_plugin->priv->hour_shadow_svg_handle);
-    g_object_ref(desktop_plugin->priv->minute_svg_handle);
-    g_object_ref(desktop_plugin->priv->minute_shadow_svg_handle);
-    g_object_ref(desktop_plugin->priv->second_svg_handle);
-    g_object_ref(desktop_plugin->priv->second_shadow_svg_handle);
+
+    if(desktop_plugin->priv->hour_svg_handle)
+      g_object_ref(desktop_plugin->priv->hour_svg_handle);
+    if(desktop_plugin->priv->hour_shadow_svg_handle)
+      g_object_ref(desktop_plugin->priv->hour_shadow_svg_handle);
+    if(desktop_plugin->priv->minute_svg_handle)
+      g_object_ref(desktop_plugin->priv->minute_svg_handle);
+    if(desktop_plugin->priv->minute_shadow_svg_handle)
+      g_object_ref(desktop_plugin->priv->minute_shadow_svg_handle);
+    if(desktop_plugin->priv->second_svg_handle)
+      g_object_ref(desktop_plugin->priv->second_svg_handle);
+    if(desktop_plugin->priv->second_shadow_svg_handle)
+      g_object_ref(desktop_plugin->priv->second_shadow_svg_handle);
   }
   desktop_clock_widget_free_svg_theme(theme);
 }
@@ -1427,7 +1438,8 @@ desktop_clock_widget_expose(GtkWidget* widget, GdkEventExpose *event)
   cairo_save(cr);
 
   cairo_rotate(cr, hour_angle);
-  rsvg_handle_render_cairo(desktop_plugin->priv->hour_svg_handle, cr);
+  if(desktop_plugin->priv->hour_svg_handle)
+    rsvg_handle_render_cairo(desktop_plugin->priv->hour_svg_handle, cr);
   cairo_restore(cr);
 
   cairo_save(cr);
@@ -1435,12 +1447,14 @@ desktop_clock_widget_expose(GtkWidget* widget, GdkEventExpose *event)
 		  -0.75, 
 		  0.75);
   cairo_rotate(cr, hour_angle);
-  rsvg_handle_render_cairo(desktop_plugin->priv->hour_shadow_svg_handle, cr);
+  if(desktop_plugin->priv->hour_shadow_svg_handle)
+    rsvg_handle_render_cairo(desktop_plugin->priv->hour_shadow_svg_handle, cr);
   cairo_restore(cr);
 
   cairo_save(cr);
   cairo_rotate(cr, min_angle);
-  rsvg_handle_render_cairo(desktop_plugin->priv->minute_svg_handle, cr);
+  if(desktop_plugin->priv->minute_svg_handle)
+    rsvg_handle_render_cairo(desktop_plugin->priv->minute_svg_handle, cr);
   cairo_restore(cr);
 
   cairo_save(cr);
@@ -1448,14 +1462,16 @@ desktop_clock_widget_expose(GtkWidget* widget, GdkEventExpose *event)
 		  -0.75, 
 		  0.75);
   cairo_rotate(cr, min_angle);
-  rsvg_handle_render_cairo(desktop_plugin->priv->minute_shadow_svg_handle, cr);
+  if(desktop_plugin->priv->minute_shadow_svg_handle)
+    rsvg_handle_render_cairo(desktop_plugin->priv->minute_shadow_svg_handle, cr);
   cairo_restore(cr);
 
   if(desktop_plugin->priv->show_seconds)
   {
     cairo_save(cr);
     cairo_rotate(cr, 2*M_PI/60.0*seconds);
-    rsvg_handle_render_cairo(desktop_plugin->priv->second_svg_handle, cr);
+    if(desktop_plugin->priv->second_svg_handle)
+      rsvg_handle_render_cairo(desktop_plugin->priv->second_svg_handle, cr);
     cairo_restore(cr);
 
     cairo_save(cr);
@@ -1463,7 +1479,8 @@ desktop_clock_widget_expose(GtkWidget* widget, GdkEventExpose *event)
 		    -0.75, 
 		    0.75);
     cairo_rotate(cr, 2*M_PI/60.0*seconds);
-    rsvg_handle_render_cairo(desktop_plugin->priv->second_shadow_svg_handle, cr);
+    if(desktop_plugin->priv->second_shadow_svg_handle)
+      rsvg_handle_render_cairo(desktop_plugin->priv->second_shadow_svg_handle, cr);
     cairo_restore(cr);
   }
 
